==> nodejs_interop-0.5.0.tar.gz: test/js/json_test.dart <==
import 'dart:js_util';
import 'package:nodejs_interop/nodejs_interop.dart';
import 'package:test/test.dart';

/// Tests the features of the [Json] class.
void main() => group('Json', () {
  group('.parse()', () {
    test('should return a `null` reference for the string "null"', () {
      expect(Json.parse('null'), isNull);
    });

    test('should return a boolean value for the string "true" or "false"', () {
      expect(Json.parse('false'), isFalse);
      expect(Json.parse('true'), isTrue);
    });

    test('should return a number for a numeric string', () {
      expect(Json.parse('123'), equals(123));
      expect(Json.parse('123.456'), equals(123.456));
    });

    test('should return a string for a quoted string', () {
      expect(Json.parse('"foo"'), equals('foo'));
      expect(Json.parse('"bar"'), equals('bar'));
    });

    test('should return a list for a string like "[]"', () {
      expect(Json.parse('[]'), allOf(isList, isEmpty));
      expect(Json.parse('[1,2,3]'), allOf(isList, orderedEquals([1, 2, 3])));
      expect(Json.parse('["ab","c","def"]'), allOf(isList, orderedEquals(['ab', 'c', 'def'])));
    });

    test('should return an object for a string like "{}"', () {
      var object = Json.parse('{"foo":"bar"}');
      expect(getProperty(object, 'foo'), equals('bar'));

      object = Json.parse('{"foo":"bar","baz":{"qux":"quux"}}');
      expect(getProperty(object, 'foo'), equals('bar'));

      var subObject = getProperty(object, 'baz');
      expect(getProperty(subObject, 'qux'), equals('quux'));
    });
  });

  group('.stringify()', () {
    test('should return the string "null" for a `null` reference', () {
      expect(Json.stringify(null), equals('null'));
    });

    test('should return the string "true" or "false" for a boolean', () {
      expect(Json.stringify(false), equals('false'));
      expect(Json.stringify(true), equals('true'));
    });

    test('should return a numeric string for a number', () {
      expect(Json.stringify(123), equals('123'));
      expect(Json.stringify(123.456), equals('123.456'));
    });

    test('should return a quoted string for a string', () {
      expect(Json.stringify('foo'), equals('"foo"'));
      expect(Json.stringify('bar'), equals('"bar"'));
    });

    test('should return a string like "{}" for a JavaScript object', () {
      var object = newObject();
      expect(Json.stringify(object), equals('{}'));
      setProperty(object, 'foo', 'bar');
      expect(Json.stringify(object), equals('{"foo":"bar"}'));
      setProperty(object, 'baz', newObject());
      expect(Json.stringify(object), equals('{"foo":"bar","baz":{}}'));
    });
  });
});

==> nodejs_interop-0.7.0.tar.gz: test/js/json_test.dart <==
import 'dart:js_util';
import 'package:nodejs_interop/nodejs_interop.dart';
import 'package:test/test.dart';

/// Tests the features of the [Json] class.
void main() => group('Json', () {
  group('.parse()', () {
    test('should return a `null` reference for the string "null"', () {
      expect(Json.parse('null'), isNull);
    });

    test('should return a boolean value for the string "true" or "false"', () {
      expect(Json.parse('false'), isFalse);
      expect(Json.parse('true'), isTrue);
    });

    test('should return a number for a numeric string', () {
      expect(Json.parse('123'), equals(123));
      expect(Json.parse('123.456'), equals(123.456));
    });

    test('should return a string for a quoted string', () {
      expect(Json.parse('"foo"'), equals('foo'));
      expect(Json.parse('"bar"'), equals('bar'));
    });

    test('should return a list for a string like "[]"', () {
      expect(Json.parse('[]'), allOf(isList, isEmpty));
      expect(Json.parse('[1,2,3]'), allOf(isList, orderedEquals([1, 2, 3])));
      expect(Json.parse('["ab","c","def"]'), allOf(isList, orderedEquals(['ab', 'c', 'def'])));
    });

    test('should return an object for a string like "{}"', () {
      var object = Json.parse('{"foo":"bar"}');
      expect(getProperty(object, 'foo'), equals('bar'));

      object = Json.parse('{"foo":"bar","baz":{"qux":"quux"}}');
      expect(getProperty(object, 'foo'), equals('bar'));
      expect(getProperty(getProperty(object, 'baz'), 'qux'), equals('quux'));
    });
  });

  group('.stringify()', () {
    test('should return the string "null" for a `null` reference', () {
      expect(Json.stringify(null), equals('null'));
    });

    test('should return the string "true" or "false" for a boolean', () {
      expect(Json.stringify(false), equals('false'));
      expect(Json.stringify(true), equals('true'));
    });

    test('should return a numeric string for a number', () {
      expect(Json.stringify(123), equals('123'));
      expect(Json.stringify(123.456), equals('123.456'));
    });

    test('should return a quoted string for a string', () {
      expect(Json.stringify('foo'), equals('"foo"'));
      expect(Json.stringify('bar'), equals('"bar"'));
    });

    test('should return a string like "{}" for a JavaScript object', () {
      var object = newObject();
      expect(Json.stringify(object), equals('{}'));
      setProperty(object, 'foo', 'bar');
      expect(Json.stringify(object), equals('{"foo":"bar"}'));
      setProperty(object, 'baz', newObject());
      expect(Json.stringify(object), equals('{"foo":"bar","baz":{}}'));
    });
  });
});
